@@ -117,7 +117,7 @@ def download(url, filename):
         log.info('process %s for %s beaten to it', os.getpid(), url)
         return
 
-    log.info('downloading %s in process %s...', url, os.getpid())
+    log.info('downloading %s to %s in process %s...', url, os.getpid())
     try:
         # open straight away so the file's on disk
         local_path = os.path.join(pkgdir, filename)
@@ -130,16 +130,18 @@ def download(url, filename):
             if http_code != 200:
                 log.info('url %s got HTTP %d, cancelling download', url,
                     http_code)
-                with open(filename + '.cancel', 'w') as cancel_file:
+                with open(local_path + '.cancel', 'w') as cancel_file:
                     cancel_file.write('HTTP %d' % http_code)
+                # nuke the partial file
+                os.remove(local_path)
                 # don't attempt to re-download
-                os.remove(filename + '.url')
+                os.remove(local_path + '.url')
                 log.info('wrote cancel file %s.cancel', filename)
                 return
 
             # get file size and store it away
             size = int(content.info()['Content-Length'])
-            with open(filename + '.size', 'w') as size_file:
+            with open(local_path + '.size', 'w') as size_file:
                 size_file.write(str(size))
 
             # grab data
@@ -159,14 +161,14 @@ def download(url, filename):
                 log.error('%s fetched %dB != Content-Length %dB', filename,
                     total, size)
                 # remove partial and size file
-                os.remove(filename)
-                os.remove(filename + '.size')
+                os.remove(local_path)
+                os.remove(local_path + '.size')
                 # TODO cancel current downloads of partial!
                 return
 
         log.info('... fetched into %s', filename)
-        os.remove(filename + '.url')
-        os.remove(filename + '.size')
+        os.remove(local_path + '.url')
+        os.remove(local_path + '.size')
     finally:
         lock.release()
 
